@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-#  Copyright (c) 2019-2020 Gabriel Sanhueza.
+#  Copyright (c) 2019-2021 Gabriel Sanhueza.
 #
 #  Distributed under the MIT License.
 #  See LICENSE for more info.
@@ -11,8 +11,11 @@ from ..drawables.meshgl import MeshGL
 from ..drawables.blockgl import BlockGL
 from ..drawables.linegl import LineGL
 from ..drawables.pointgl import PointGL
-from ..drawables.tubegl import TubeGL
 from ..drawables.textgl import TextGL
+from ..drawables.tubegl import TubeGL
+
+from ..drawables.blocklegacygl import BlockLegacyGL
+from ..drawables.tubelegacygl import TubeLegacyGL
 
 from ..glprograms.meshprogram import MeshProgram
 from ..glprograms.wireprogram import WireProgram
@@ -25,6 +28,7 @@ from ..glprograms.blocklegacyprogram import BlockLegacyProgram
 from ..glprograms.lineprogram import LineProgram
 from ..glprograms.pointprogram import PointProgram
 from ..glprograms.tubeprogram import TubeProgram
+from ..glprograms.tubelegacyprogram import TubeLegacyProgram
 
 from ..glprograms.meshphantomprogram import MeshPhantomProgram
 from ..glprograms.xsectionmeshprogram import XSectionMeshProgram
@@ -35,14 +39,17 @@ from ..glprograms.textprogram import TextProgram
 
 class GLDrawableCollection(GLCollection):
     def generate_associations(self):
-        # Lines/Tubes/Points
+        # Lines/Points
         self.associate(LineProgram(), LineGL)
-        self.associate(TubeProgram(), TubeGL)
         self.associate(PointProgram(), PointGL)
 
+        # Tubes
+        self.associate(TubeLegacyProgram(), TubeLegacyGL)
+        self.associate(TubeProgram(), TubeGL)
+
         # Blocks
-        self.associate(BlockLegacyProgram(), BlockGL, selector=lambda x: x.is_legacy)
-        self.associate(BlockProgram(), BlockGL, selector=lambda x: x.is_standard)
+        self.associate(BlockLegacyProgram(), BlockLegacyGL)
+        self.associate(BlockProgram(), BlockGL)
 
         # Meshes
         self.associate(MeshProgram(), MeshGL, selector=lambda x: x.is_standard)
@@ -52,8 +59,8 @@ class GLDrawableCollection(GLCollection):
 
         # XSection
         self.associate(MeshPhantomProgram(), MeshGL, selector=lambda x: x.is_phantom)
-        self.associate(XSectionBlockProgram(), BlockGL, selector=lambda x: x.is_cross_sectionable)
-        self.associate(XSectionMeshProgram(), MeshGL, selector=lambda x: x.is_cross_sectionable)
+        self.associate(XSectionBlockProgram(), BlockGL, selector=lambda x: x.is_cross_sectioned)
+        self.associate(XSectionMeshProgram(), MeshGL, selector=lambda x: x.is_cross_sectioned)
 
         # Text
         self.associate(TextProgram(), TextGL)
