@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-#  Copyright (c) 2019-2020 Gabriel Sanhueza.
+#  Copyright (c) 2019-2021 Gabriel Sanhueza.
 #
 #  Distributed under the MIT License.
 #  See LICENSE for more info.
@@ -33,7 +33,6 @@ from .drawables.meshgl import MeshGL
 from .drawables.pointgl import PointGL
 from .drawables.tubegl import TubeGL
 from .drawables.textgl import TextGL
-from .drawables.gridgl import GridGL
 
 from .drawablefactory import DrawableFactory
 from .fpscounter import FPSCounter
@@ -115,7 +114,6 @@ class IntegrableViewer(QOpenGLWidget):
         self._rotation_center = np.array([0.0, 0.0, 0.0])
         self._rotation_angle = np.array([0.0, 0.0, 0.0])
         self._camera_position = np.array([0.0, 0.0, 200.0])
-        self._rendering_offset = np.array([0.0, 0.0, 0.0])
 
         # Cross-section data
         self.last_cross_origin = np.asarray([0.0, 0.0, 0.0])
@@ -215,7 +213,7 @@ class IntegrableViewer(QOpenGLWidget):
         if self.current_projection == 'Perspective':
             self.proj_matrix.perspective(self.fov, aspect, 1.0, 100000.0)
         else:  # if self.current_projection == 'Orthographic':
-            z = self.off_center[2] * 0.65
+            z = self.off_center[2]
             self.proj_matrix.ortho(-z, z, -z / self.aspect, z / aspect, 0.0, 100000.0)
 
     @staticmethod
@@ -312,11 +310,7 @@ class IntegrableViewer(QOpenGLWidget):
     """
     @property
     def rendering_offset(self) -> np.ndarray:
-        return self._rendering_offset
-
-    @rendering_offset.setter
-    def rendering_offset(self, value: iter) -> None:
-        self._rendering_offset = np.asarray(value)
+        return np.zeros(3)  # -self.rotation_center
 
     @property
     def render_camera_position(self) -> np.ndarray:
@@ -460,6 +454,9 @@ class IntegrableViewer(QOpenGLWidget):
         if collection is None:
             collection = self.drawable_collection
 
+        # Update shared settings
+        drawable.is_cross_sectioned = self.is_cross_sectioned
+
         # Register in collection
         drawable.add_observer(self)
         collection.add(drawable)
@@ -697,10 +694,6 @@ class IntegrableViewer(QOpenGLWidget):
 
         return min_all, max_all
 
-    def fix_wobbling(self) -> None:
-        # Update offset to minimize wobbling
-        self.rendering_offset = -self.rotation_center
-
     """
     Utilities
     """
@@ -905,7 +898,7 @@ class IntegrableViewer(QOpenGLWidget):
         self.is_cross_sectioned = status
 
         for m in self.get_all_meshes() + self.get_all_blocks():
-            m.is_cross_sectionable = status
+            m.is_cross_sectioned = status
 
         self.signal_xsection_updated.emit()
 
